# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetCategoryResult',
    'AwaitableGetCategoryResult',
    'get_category',
    'get_category_output',
]

@pulumi.output_type
class GetCategoryResult:
    """
    A collection of values returned by getCategory.
    """
    def __init__(__self__, category_id=None, compartment_id=None, compartment_name=None, description=None, estimated_cost_saving=None, extended_metadata=None, id=None, name=None, recommendation_counts=None, resource_counts=None, state=None, time_created=None, time_updated=None):
        if category_id and not isinstance(category_id, str):
            raise TypeError("Expected argument 'category_id' to be a str")
        pulumi.set(__self__, "category_id", category_id)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_name and not isinstance(compartment_name, str):
            raise TypeError("Expected argument 'compartment_name' to be a str")
        pulumi.set(__self__, "compartment_name", compartment_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if estimated_cost_saving and not isinstance(estimated_cost_saving, float):
            raise TypeError("Expected argument 'estimated_cost_saving' to be a float")
        pulumi.set(__self__, "estimated_cost_saving", estimated_cost_saving)
        if extended_metadata and not isinstance(extended_metadata, dict):
            raise TypeError("Expected argument 'extended_metadata' to be a dict")
        pulumi.set(__self__, "extended_metadata", extended_metadata)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if recommendation_counts and not isinstance(recommendation_counts, list):
            raise TypeError("Expected argument 'recommendation_counts' to be a list")
        pulumi.set(__self__, "recommendation_counts", recommendation_counts)
        if resource_counts and not isinstance(resource_counts, list):
            raise TypeError("Expected argument 'resource_counts' to be a list")
        pulumi.set(__self__, "resource_counts", resource_counts)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="categoryId")
    def category_id(self) -> str:
        return pulumi.get(self, "category_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the tenancy. The tenancy is the root compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentName")
    def compartment_name(self) -> str:
        """
        The name associated with the compartment.
        """
        return pulumi.get(self, "compartment_name")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Text describing the category.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="estimatedCostSaving")
    def estimated_cost_saving(self) -> float:
        """
        The estimated cost savings, in dollars, for the category.
        """
        return pulumi.get(self, "estimated_cost_saving")

    @property
    @pulumi.getter(name="extendedMetadata")
    def extended_metadata(self) -> Mapping[str, Any]:
        """
        Additional metadata key/value pairs for the category.
        """
        return pulumi.get(self, "extended_metadata")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name assigned to the category.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="recommendationCounts")
    def recommendation_counts(self) -> Sequence['outputs.GetCategoryRecommendationCountResult']:
        """
        An array of `RecommendationCount` objects grouped by the level of importance assigned to the recommendation.
        """
        return pulumi.get(self, "recommendation_counts")

    @property
    @pulumi.getter(name="resourceCounts")
    def resource_counts(self) -> Sequence['outputs.GetCategoryResourceCountResult']:
        """
        An array of `ResourceCount` objects grouped by the status of the recommendation.
        """
        return pulumi.get(self, "resource_counts")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The category's current state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the category details were created, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the category details were last updated, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetCategoryResult(GetCategoryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCategoryResult(
            category_id=self.category_id,
            compartment_id=self.compartment_id,
            compartment_name=self.compartment_name,
            description=self.description,
            estimated_cost_saving=self.estimated_cost_saving,
            extended_metadata=self.extended_metadata,
            id=self.id,
            name=self.name,
            recommendation_counts=self.recommendation_counts,
            resource_counts=self.resource_counts,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_category(category_id: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCategoryResult:
    """
    This data source provides details about a specific Category resource in Oracle Cloud Infrastructure Optimizer service.

    Gets the category that corresponds to the specified OCID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_category = oci.Optimizer.get_category(category_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str category_id: The unique OCID associated with the category.
    """
    __args__ = dict()
    __args__['categoryId'] = category_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Optimizer/getCategory:getCategory', __args__, opts=opts, typ=GetCategoryResult).value

    return AwaitableGetCategoryResult(
        category_id=__ret__.category_id,
        compartment_id=__ret__.compartment_id,
        compartment_name=__ret__.compartment_name,
        description=__ret__.description,
        estimated_cost_saving=__ret__.estimated_cost_saving,
        extended_metadata=__ret__.extended_metadata,
        id=__ret__.id,
        name=__ret__.name,
        recommendation_counts=__ret__.recommendation_counts,
        resource_counts=__ret__.resource_counts,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_category)
def get_category_output(category_id: Optional[pulumi.Input[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCategoryResult]:
    """
    This data source provides details about a specific Category resource in Oracle Cloud Infrastructure Optimizer service.

    Gets the category that corresponds to the specified OCID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_category = oci.Optimizer.get_category(category_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str category_id: The unique OCID associated with the category.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MysqlConfigurationArgs', 'MysqlConfiguration']

@pulumi.input_type
class MysqlConfigurationArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 shape_name: pulumi.Input[str],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 init_variables: Optional[pulumi.Input['MysqlConfigurationInitVariablesArgs']] = None,
                 parent_configuration_id: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input['MysqlConfigurationVariablesArgs']] = None):
        """
        The set of arguments for constructing a MysqlConfiguration resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[str] shape_name: The name of the associated Shape.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) User-provided data about the Configuration.
        :param pulumi.Input[str] display_name: (Updatable) The display name of the Configuration.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input['MysqlConfigurationInitVariablesArgs'] init_variables: User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        :param pulumi.Input[str] parent_configuration_id: The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        :param pulumi.Input['MysqlConfigurationVariablesArgs'] variables: User-defined service variables.
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "shape_name", shape_name)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if init_variables is not None:
            pulumi.set(__self__, "init_variables", init_variables)
        if parent_configuration_id is not None:
            pulumi.set(__self__, "parent_configuration_id", parent_configuration_id)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="shapeName")
    def shape_name(self) -> pulumi.Input[str]:
        """
        The name of the associated Shape.
        """
        return pulumi.get(self, "shape_name")

    @shape_name.setter
    def shape_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "shape_name", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) User-provided data about the Configuration.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The display name of the Configuration.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="initVariables")
    def init_variables(self) -> Optional[pulumi.Input['MysqlConfigurationInitVariablesArgs']]:
        """
        User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        """
        return pulumi.get(self, "init_variables")

    @init_variables.setter
    def init_variables(self, value: Optional[pulumi.Input['MysqlConfigurationInitVariablesArgs']]):
        pulumi.set(self, "init_variables", value)

    @property
    @pulumi.getter(name="parentConfigurationId")
    def parent_configuration_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        """
        return pulumi.get(self, "parent_configuration_id")

    @parent_configuration_id.setter
    def parent_configuration_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_configuration_id", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input['MysqlConfigurationVariablesArgs']]:
        """
        User-defined service variables.
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input['MysqlConfigurationVariablesArgs']]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class _MysqlConfigurationState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 init_variables: Optional[pulumi.Input['MysqlConfigurationInitVariablesArgs']] = None,
                 parent_configuration_id: Optional[pulumi.Input[str]] = None,
                 shape_name: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input['MysqlConfigurationVariablesArgs']] = None):
        """
        Input properties used for looking up and filtering MysqlConfiguration resources.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) User-provided data about the Configuration.
        :param pulumi.Input[str] display_name: (Updatable) The display name of the Configuration.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input['MysqlConfigurationInitVariablesArgs'] init_variables: User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        :param pulumi.Input[str] parent_configuration_id: The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        :param pulumi.Input[str] shape_name: The name of the associated Shape.
        :param pulumi.Input[str] state: The current state of the Configuration.
        :param pulumi.Input[str] time_created: The date and time the Configuration was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        :param pulumi.Input[str] time_updated: The date and time the Configuration was last updated, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        :param pulumi.Input[str] type: The Configuration type, DEFAULT or CUSTOM.
        :param pulumi.Input['MysqlConfigurationVariablesArgs'] variables: User-defined service variables.
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if init_variables is not None:
            pulumi.set(__self__, "init_variables", init_variables)
        if parent_configuration_id is not None:
            pulumi.set(__self__, "parent_configuration_id", parent_configuration_id)
        if shape_name is not None:
            pulumi.set(__self__, "shape_name", shape_name)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) User-provided data about the Configuration.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The display name of the Configuration.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="initVariables")
    def init_variables(self) -> Optional[pulumi.Input['MysqlConfigurationInitVariablesArgs']]:
        """
        User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        """
        return pulumi.get(self, "init_variables")

    @init_variables.setter
    def init_variables(self, value: Optional[pulumi.Input['MysqlConfigurationInitVariablesArgs']]):
        pulumi.set(self, "init_variables", value)

    @property
    @pulumi.getter(name="parentConfigurationId")
    def parent_configuration_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        """
        return pulumi.get(self, "parent_configuration_id")

    @parent_configuration_id.setter
    def parent_configuration_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_configuration_id", value)

    @property
    @pulumi.getter(name="shapeName")
    def shape_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the associated Shape.
        """
        return pulumi.get(self, "shape_name")

    @shape_name.setter
    def shape_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shape_name", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the Configuration.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the Configuration was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the Configuration was last updated, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The Configuration type, DEFAULT or CUSTOM.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input['MysqlConfigurationVariablesArgs']]:
        """
        User-defined service variables.
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input['MysqlConfigurationVariablesArgs']]):
        pulumi.set(self, "variables", value)


class MysqlConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 init_variables: Optional[pulumi.Input[pulumi.InputType['MysqlConfigurationInitVariablesArgs']]] = None,
                 parent_configuration_id: Optional[pulumi.Input[str]] = None,
                 shape_name: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input[pulumi.InputType['MysqlConfigurationVariablesArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Mysql Configuration resource in Oracle Cloud Infrastructure MySQL Database service.

        Creates a new Configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_mysql_configuration = oci.mysql.MysqlConfiguration("testMysqlConfiguration",
            compartment_id=var["compartment_id"],
            shape_name=oci_mysql_shape["test_shape"]["name"],
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            description=var["mysql_configuration_description"],
            display_name=var["mysql_configuration_display_name"],
            freeform_tags={
                "bar-key": "value",
            },
            init_variables=oci.mysql.MysqlConfigurationInitVariablesArgs(
                lower_case_table_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            parent_configuration_id=oci_audit_configuration["test_configuration"]["id"],
            variables=oci.mysql.MysqlConfigurationVariablesArgs(
                autocommit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                big_tables=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_expire_logs_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_row_metadata=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_row_value_options=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_transaction_compression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                completion_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                connect_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                connection_memory_chunk_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                connection_memory_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                cte_max_recursion_depth=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                default_authentication_plugin=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                foreign_key_checks=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                generated_random_password_length=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                global_connection_memory_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                global_connection_memory_tracking=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                group_replication_consistency=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                information_schema_stats_expiry=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_buffer_pool_dump_pct=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_buffer_pool_instances=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_buffer_pool_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ddl_buffer_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ddl_threads=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_enable_stopword=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_max_token_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_min_token_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_num_word_optimize=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_result_cache_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_server_stopword_table=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_lock_wait_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_log_writer_threads=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_max_purge_lag=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_max_purge_lag_delay=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_stats_persistent_sample_pages=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_stats_transient_sample_pages=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                interactive_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                local_infile=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mandatory_roles=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_allowed_packet=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_binlog_cache_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_connect_errors=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_connections=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_execution_time=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_heap_table_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_prepared_stmt_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysql_firewall_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysql_zstd_default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_connect_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_deflate_default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_deflate_max_client_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_document_id_unique_prefix=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_enable_hello_notice=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_idle_worker_thread_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_interactive_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_lz4default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_lz4max_client_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_max_allowed_packet=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_min_worker_threads=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_read_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_wait_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_write_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_zstd_default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_zstd_max_client_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                net_read_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                net_write_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                parser_max_mem_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                query_alloc_block_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                query_prealloc_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                regexp_time_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sort_buffer_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sql_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sql_require_primary_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sql_warnings=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                thread_pool_dedicated_listeners=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                thread_pool_max_transactions_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                time_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                tmp_table_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                transaction_isolation=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                wait_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        MysqlConfigurations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Mysql/mysqlConfiguration:MysqlConfiguration test_mysql_configuration "configurations/{configurationId}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) User-provided data about the Configuration.
        :param pulumi.Input[str] display_name: (Updatable) The display name of the Configuration.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[pulumi.InputType['MysqlConfigurationInitVariablesArgs']] init_variables: User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        :param pulumi.Input[str] parent_configuration_id: The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        :param pulumi.Input[str] shape_name: The name of the associated Shape.
        :param pulumi.Input[pulumi.InputType['MysqlConfigurationVariablesArgs']] variables: User-defined service variables.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MysqlConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Mysql Configuration resource in Oracle Cloud Infrastructure MySQL Database service.

        Creates a new Configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_mysql_configuration = oci.mysql.MysqlConfiguration("testMysqlConfiguration",
            compartment_id=var["compartment_id"],
            shape_name=oci_mysql_shape["test_shape"]["name"],
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            description=var["mysql_configuration_description"],
            display_name=var["mysql_configuration_display_name"],
            freeform_tags={
                "bar-key": "value",
            },
            init_variables=oci.mysql.MysqlConfigurationInitVariablesArgs(
                lower_case_table_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            parent_configuration_id=oci_audit_configuration["test_configuration"]["id"],
            variables=oci.mysql.MysqlConfigurationVariablesArgs(
                autocommit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                big_tables=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_expire_logs_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_row_metadata=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_row_value_options=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                binlog_transaction_compression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                completion_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                connect_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                connection_memory_chunk_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                connection_memory_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                cte_max_recursion_depth=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                default_authentication_plugin=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                foreign_key_checks=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                generated_random_password_length=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                global_connection_memory_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                global_connection_memory_tracking=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                group_replication_consistency=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                information_schema_stats_expiry=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_buffer_pool_dump_pct=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_buffer_pool_instances=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_buffer_pool_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ddl_buffer_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ddl_threads=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_enable_stopword=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_max_token_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_min_token_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_num_word_optimize=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_result_cache_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_ft_server_stopword_table=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_lock_wait_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_log_writer_threads=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_max_purge_lag=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_max_purge_lag_delay=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_stats_persistent_sample_pages=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                innodb_stats_transient_sample_pages=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                interactive_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                local_infile=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mandatory_roles=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_allowed_packet=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_binlog_cache_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_connect_errors=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_connections=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_execution_time=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_heap_table_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_prepared_stmt_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysql_firewall_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysql_zstd_default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_connect_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_deflate_default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_deflate_max_client_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_document_id_unique_prefix=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_enable_hello_notice=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_idle_worker_thread_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_interactive_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_lz4default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_lz4max_client_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_max_allowed_packet=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_min_worker_threads=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_read_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_wait_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_write_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_zstd_default_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                mysqlx_zstd_max_client_compression_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                net_read_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                net_write_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                parser_max_mem_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                query_alloc_block_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                query_prealloc_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                regexp_time_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sort_buffer_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sql_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sql_require_primary_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                sql_warnings=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                thread_pool_dedicated_listeners=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                thread_pool_max_transactions_limit=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                time_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                tmp_table_size=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                transaction_isolation=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                wait_timeout=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        MysqlConfigurations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Mysql/mysqlConfiguration:MysqlConfiguration test_mysql_configuration "configurations/{configurationId}"
        ```

        :param str resource_name: The name of the resource.
        :param MysqlConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MysqlConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 init_variables: Optional[pulumi.Input[pulumi.InputType['MysqlConfigurationInitVariablesArgs']]] = None,
                 parent_configuration_id: Optional[pulumi.Input[str]] = None,
                 shape_name: Optional[pulumi.Input[str]] = None,
                 variables: Optional[pulumi.Input[pulumi.InputType['MysqlConfigurationVariablesArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MysqlConfigurationArgs.__new__(MysqlConfigurationArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["init_variables"] = init_variables
            __props__.__dict__["parent_configuration_id"] = parent_configuration_id
            if shape_name is None and not opts.urn:
                raise TypeError("Missing required property 'shape_name'")
            __props__.__dict__["shape_name"] = shape_name
            __props__.__dict__["variables"] = variables
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
            __props__.__dict__["type"] = None
        super(MysqlConfiguration, __self__).__init__(
            'oci:Mysql/mysqlConfiguration:MysqlConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            init_variables: Optional[pulumi.Input[pulumi.InputType['MysqlConfigurationInitVariablesArgs']]] = None,
            parent_configuration_id: Optional[pulumi.Input[str]] = None,
            shape_name: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            variables: Optional[pulumi.Input[pulumi.InputType['MysqlConfigurationVariablesArgs']]] = None) -> 'MysqlConfiguration':
        """
        Get an existing MysqlConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) User-provided data about the Configuration.
        :param pulumi.Input[str] display_name: (Updatable) The display name of the Configuration.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[pulumi.InputType['MysqlConfigurationInitVariablesArgs']] init_variables: User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        :param pulumi.Input[str] parent_configuration_id: The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        :param pulumi.Input[str] shape_name: The name of the associated Shape.
        :param pulumi.Input[str] state: The current state of the Configuration.
        :param pulumi.Input[str] time_created: The date and time the Configuration was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        :param pulumi.Input[str] time_updated: The date and time the Configuration was last updated, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        :param pulumi.Input[str] type: The Configuration type, DEFAULT or CUSTOM.
        :param pulumi.Input[pulumi.InputType['MysqlConfigurationVariablesArgs']] variables: User-defined service variables.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MysqlConfigurationState.__new__(_MysqlConfigurationState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["init_variables"] = init_variables
        __props__.__dict__["parent_configuration_id"] = parent_configuration_id
        __props__.__dict__["shape_name"] = shape_name
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        __props__.__dict__["type"] = type
        __props__.__dict__["variables"] = variables
        return MysqlConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) User-provided data about the Configuration.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The display name of the Configuration.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="initVariables")
    def init_variables(self) -> pulumi.Output['outputs.MysqlConfigurationInitVariables']:
        """
        User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        """
        return pulumi.get(self, "init_variables")

    @property
    @pulumi.getter(name="parentConfigurationId")
    def parent_configuration_id(self) -> pulumi.Output[str]:
        """
        The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
        """
        return pulumi.get(self, "parent_configuration_id")

    @property
    @pulumi.getter(name="shapeName")
    def shape_name(self) -> pulumi.Output[str]:
        """
        The name of the associated Shape.
        """
        return pulumi.get(self, "shape_name")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the Configuration.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the Configuration was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The date and time the Configuration was last updated, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The Configuration type, DEFAULT or CUSTOM.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def variables(self) -> pulumi.Output['outputs.MysqlConfigurationVariables']:
        """
        User-defined service variables.
        """
        return pulumi.get(self, "variables")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCpesResult',
    'AwaitableGetCpesResult',
    'get_cpes',
    'get_cpes_output',
]

@pulumi.output_type
class GetCpesResult:
    """
    A collection of values returned by getCpes.
    """
    def __init__(__self__, compartment_id=None, cpes=None, filters=None, id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if cpes and not isinstance(cpes, list):
            raise TypeError("Expected argument 'cpes' to be a list")
        pulumi.set(__self__, "cpes", cpes)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the CPE.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def cpes(self) -> Sequence['outputs.GetCpesCpeResult']:
        """
        The list of cpes.
        """
        return pulumi.get(self, "cpes")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetCpesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetCpesResult(GetCpesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCpesResult(
            compartment_id=self.compartment_id,
            cpes=self.cpes,
            filters=self.filters,
            id=self.id)


def get_cpes(compartment_id: Optional[str] = None,
             filters: Optional[Sequence[pulumi.InputType['GetCpesFilterArgs']]] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCpesResult:
    """
    This data source provides the list of Cpes in Oracle Cloud Infrastructure Core service.

    Lists the customer-premises equipment objects (CPEs) in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_cpes = oci.Core.get_cpes(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getCpes:getCpes', __args__, opts=opts, typ=GetCpesResult).value

    return AwaitableGetCpesResult(
        compartment_id=__ret__.compartment_id,
        cpes=__ret__.cpes,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_cpes)
def get_cpes_output(compartment_id: Optional[pulumi.Input[str]] = None,
                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetCpesFilterArgs']]]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCpesResult]:
    """
    This data source provides the list of Cpes in Oracle Cloud Infrastructure Core service.

    Lists the customer-premises equipment objects (CPEs) in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_cpes = oci.Core.get_cpes(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VolumeBackupPolicyArgs', 'VolumeBackupPolicy']

@pulumi.input_type
class VolumeBackupPolicyArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 destination_region: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]]] = None):
        """
        The set of arguments for constructing a VolumeBackupPolicy resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] destination_region: (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]] schedules: (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if destination_region is not None:
            pulumi.set(__self__, "destination_region", destination_region)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if schedules is not None:
            pulumi.set(__self__, "schedules", schedules)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="destinationRegion")
    def destination_region(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        """
        return pulumi.get(self, "destination_region")

    @destination_region.setter
    def destination_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_region", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def schedules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]]]:
        """
        (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        """
        return pulumi.get(self, "schedules")

    @schedules.setter
    def schedules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]]]):
        pulumi.set(self, "schedules", value)


@pulumi.input_type
class _VolumeBackupPolicyState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 destination_region: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VolumeBackupPolicy resources.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] destination_region: (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]] schedules: (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        :param pulumi.Input[str] time_created: The date and time the volume backup policy was created. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if destination_region is not None:
            pulumi.set(__self__, "destination_region", destination_region)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if schedules is not None:
            pulumi.set(__self__, "schedules", schedules)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="destinationRegion")
    def destination_region(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        """
        return pulumi.get(self, "destination_region")

    @destination_region.setter
    def destination_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_region", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def schedules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]]]:
        """
        (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        """
        return pulumi.get(self, "schedules")

    @schedules.setter
    def schedules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeBackupPolicyScheduleArgs']]]]):
        pulumi.set(self, "schedules", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the volume backup policy was created. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)


class VolumeBackupPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 destination_region: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeBackupPolicyScheduleArgs']]]]] = None,
                 __props__=None):
        """
        This resource provides the Volume Backup Policy resource in Oracle Cloud Infrastructure Core service.

        Creates a new user defined backup policy.

        For more information about Oracle defined backup policies and user defined backup policies,
        see [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_volume_backup_policy = oci.core.VolumeBackupPolicy("testVolumeBackupPolicy",
            compartment_id=var["compartment_id"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            destination_region=var["volume_backup_policy_destination_region"],
            display_name=var["volume_backup_policy_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            schedules=[oci.core.VolumeBackupPolicyScheduleArgs(
                backup_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                period=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                retention_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                day_of_month=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                day_of_week=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hour_of_day=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                month=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                offset_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                offset_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                time_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )])
        ```

        ## Import

        VolumeBackupPolicies can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Core/volumeBackupPolicy:VolumeBackupPolicy test_volume_backup_policy "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] destination_region: (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeBackupPolicyScheduleArgs']]]] schedules: (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VolumeBackupPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Volume Backup Policy resource in Oracle Cloud Infrastructure Core service.

        Creates a new user defined backup policy.

        For more information about Oracle defined backup policies and user defined backup policies,
        see [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_volume_backup_policy = oci.core.VolumeBackupPolicy("testVolumeBackupPolicy",
            compartment_id=var["compartment_id"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            destination_region=var["volume_backup_policy_destination_region"],
            display_name=var["volume_backup_policy_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            schedules=[oci.core.VolumeBackupPolicyScheduleArgs(
                backup_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                period=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                retention_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                day_of_month=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                day_of_week=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hour_of_day=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                month=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                offset_seconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                offset_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                time_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )])
        ```

        ## Import

        VolumeBackupPolicies can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Core/volumeBackupPolicy:VolumeBackupPolicy test_volume_backup_policy "id"
        ```

        :param str resource_name: The name of the resource.
        :param VolumeBackupPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VolumeBackupPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 destination_region: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeBackupPolicyScheduleArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VolumeBackupPolicyArgs.__new__(VolumeBackupPolicyArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["destination_region"] = destination_region
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["schedules"] = schedules
            __props__.__dict__["time_created"] = None
        super(VolumeBackupPolicy, __self__).__init__(
            'oci:Core/volumeBackupPolicy:VolumeBackupPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            destination_region: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            schedules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeBackupPolicyScheduleArgs']]]]] = None,
            time_created: Optional[pulumi.Input[str]] = None) -> 'VolumeBackupPolicy':
        """
        Get an existing VolumeBackupPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] destination_region: (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        :param pulumi.Input[str] display_name: (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeBackupPolicyScheduleArgs']]]] schedules: (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        :param pulumi.Input[str] time_created: The date and time the volume backup policy was created. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VolumeBackupPolicyState.__new__(_VolumeBackupPolicyState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["destination_region"] = destination_region
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["schedules"] = schedules
        __props__.__dict__["time_created"] = time_created
        return VolumeBackupPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="destinationRegion")
    def destination_region(self) -> pulumi.Output[str]:
        """
        (Updatable) The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`. See [Region Pairs](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs) for details about paired regions.
        """
        return pulumi.get(self, "destination_region")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def schedules(self) -> pulumi.Output[Optional[Sequence['outputs.VolumeBackupPolicySchedule']]]:
        """
        (Updatable) The collection of schedules for the volume backup policy. See see [Schedules](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules) in [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm) for more information.
        """
        return pulumi.get(self, "schedules")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the volume backup policy was created. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_created")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetManagedInstanceModuleStreamsResult',
    'AwaitableGetManagedInstanceModuleStreamsResult',
    'get_managed_instance_module_streams',
    'get_managed_instance_module_streams_output',
]

@pulumi.output_type
class GetManagedInstanceModuleStreamsResult:
    """
    A collection of values returned by getManagedInstanceModuleStreams.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, managed_instance_id=None, module_name=None, module_stream_on_managed_instances=None, stream_name=None, stream_status=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if managed_instance_id and not isinstance(managed_instance_id, str):
            raise TypeError("Expected argument 'managed_instance_id' to be a str")
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        if module_name and not isinstance(module_name, str):
            raise TypeError("Expected argument 'module_name' to be a str")
        pulumi.set(__self__, "module_name", module_name)
        if module_stream_on_managed_instances and not isinstance(module_stream_on_managed_instances, list):
            raise TypeError("Expected argument 'module_stream_on_managed_instances' to be a list")
        pulumi.set(__self__, "module_stream_on_managed_instances", module_stream_on_managed_instances)
        if stream_name and not isinstance(stream_name, str):
            raise TypeError("Expected argument 'stream_name' to be a str")
        pulumi.set(__self__, "stream_name", stream_name)
        if stream_status and not isinstance(stream_status, str):
            raise TypeError("Expected argument 'stream_status' to be a str")
        pulumi.set(__self__, "stream_status", stream_status)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetManagedInstanceModuleStreamsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> str:
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter(name="moduleName")
    def module_name(self) -> Optional[str]:
        """
        The name of the module that contains the stream profile
        """
        return pulumi.get(self, "module_name")

    @property
    @pulumi.getter(name="moduleStreamOnManagedInstances")
    def module_stream_on_managed_instances(self) -> Sequence['outputs.GetManagedInstanceModuleStreamsModuleStreamOnManagedInstanceResult']:
        """
        The list of module_stream_on_managed_instances.
        """
        return pulumi.get(self, "module_stream_on_managed_instances")

    @property
    @pulumi.getter(name="streamName")
    def stream_name(self) -> Optional[str]:
        """
        The name of the stream.
        """
        return pulumi.get(self, "stream_name")

    @property
    @pulumi.getter(name="streamStatus")
    def stream_status(self) -> Optional[str]:
        return pulumi.get(self, "stream_status")


class AwaitableGetManagedInstanceModuleStreamsResult(GetManagedInstanceModuleStreamsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagedInstanceModuleStreamsResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            managed_instance_id=self.managed_instance_id,
            module_name=self.module_name,
            module_stream_on_managed_instances=self.module_stream_on_managed_instances,
            stream_name=self.stream_name,
            stream_status=self.stream_status)


def get_managed_instance_module_streams(compartment_id: Optional[str] = None,
                                        filters: Optional[Sequence[pulumi.InputType['GetManagedInstanceModuleStreamsFilterArgs']]] = None,
                                        managed_instance_id: Optional[str] = None,
                                        module_name: Optional[str] = None,
                                        stream_name: Optional[str] = None,
                                        stream_status: Optional[str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagedInstanceModuleStreamsResult:
    """
    This data source provides the list of Managed Instance Module Streams in Oracle Cloud Infrastructure OS Management service.

    Retrieve a list of module streams, along with a summary of their
    status, from a managed instance.  Filters may be applied to select
    a subset of module streams based on the filter criteria.

    The 'moduleName' attribute filters against the name of a module.
    It accepts strings of the format "<module>".  If this attribute
    is defined, only streams that belong to the specified module are
    included in the result set.  If it is not defined, the request is
    not subject to this filter.

    The "status" attribute filters against the state of a module stream.
    Valid values are "ENABLED", "DISABLED", and "ACTIVE".  If the
    attribute is set to "ENABLED", only module streams that are enabled
    are included in the result set.  If the attribute is set to "DISABLED",
    only module streams that are not enabled are included in the result
    set.  If the attribute is set to "ACTIVE", only module streams that
    are active are included in the result set.  If the attribute is not
    defined, the request is not subject to this filter.

    When sorting by the display name, the result set is sorted first
    by the module name and then by the stream name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_instance_module_streams = oci.OsManagement.get_managed_instance_module_streams(managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        module_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        stream_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        stream_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources. This parameter is optional and in some cases may have no effect.
    :param str managed_instance_id: OCID for the managed instance
    :param str module_name: The name of a module.  This parameter is required if a streamName is specified.
    :param str stream_name: The name of the stream of the containing module.  This parameter is required if a profileName is specified.
    :param str stream_status: The status of the stream
           
           A stream with the "ENABLED" status can be used as a source for installing profiles.  Streams with this status are also "ACTIVE".
           
           A stream with the "DISABLED" status cannot be the source for installing profiles.  To install profiles and packages from this stream, it must be enabled.
           
           A stream with the "ACTIVE" status can be used as a source for installing profiles.  The packages that comprise the stream are also used when a matching package is installed directly.  In general, a stream can have this status if it is the default stream for the module and no stream has been explicitly enabled.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['managedInstanceId'] = managed_instance_id
    __args__['moduleName'] = module_name
    __args__['streamName'] = stream_name
    __args__['streamStatus'] = stream_status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:OsManagement/getManagedInstanceModuleStreams:getManagedInstanceModuleStreams', __args__, opts=opts, typ=GetManagedInstanceModuleStreamsResult).value

    return AwaitableGetManagedInstanceModuleStreamsResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        managed_instance_id=__ret__.managed_instance_id,
        module_name=__ret__.module_name,
        module_stream_on_managed_instances=__ret__.module_stream_on_managed_instances,
        stream_name=__ret__.stream_name,
        stream_status=__ret__.stream_status)


@_utilities.lift_output_func(get_managed_instance_module_streams)
def get_managed_instance_module_streams_output(compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                                               filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetManagedInstanceModuleStreamsFilterArgs']]]]] = None,
                                               managed_instance_id: Optional[pulumi.Input[str]] = None,
                                               module_name: Optional[pulumi.Input[Optional[str]]] = None,
                                               stream_name: Optional[pulumi.Input[Optional[str]]] = None,
                                               stream_status: Optional[pulumi.Input[Optional[str]]] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagedInstanceModuleStreamsResult]:
    """
    This data source provides the list of Managed Instance Module Streams in Oracle Cloud Infrastructure OS Management service.

    Retrieve a list of module streams, along with a summary of their
    status, from a managed instance.  Filters may be applied to select
    a subset of module streams based on the filter criteria.

    The 'moduleName' attribute filters against the name of a module.
    It accepts strings of the format "<module>".  If this attribute
    is defined, only streams that belong to the specified module are
    included in the result set.  If it is not defined, the request is
    not subject to this filter.

    The "status" attribute filters against the state of a module stream.
    Valid values are "ENABLED", "DISABLED", and "ACTIVE".  If the
    attribute is set to "ENABLED", only module streams that are enabled
    are included in the result set.  If the attribute is set to "DISABLED",
    only module streams that are not enabled are included in the result
    set.  If the attribute is set to "ACTIVE", only module streams that
    are active are included in the result set.  If the attribute is not
    defined, the request is not subject to this filter.

    When sorting by the display name, the result set is sorted first
    by the module name and then by the stream name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_instance_module_streams = oci.OsManagement.get_managed_instance_module_streams(managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        module_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        stream_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        stream_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources. This parameter is optional and in some cases may have no effect.
    :param str managed_instance_id: OCID for the managed instance
    :param str module_name: The name of a module.  This parameter is required if a streamName is specified.
    :param str stream_name: The name of the stream of the containing module.  This parameter is required if a profileName is specified.
    :param str stream_status: The status of the stream
           
           A stream with the "ENABLED" status can be used as a source for installing profiles.  Streams with this status are also "ACTIVE".
           
           A stream with the "DISABLED" status cannot be the source for installing profiles.  To install profiles and packages from this stream, it must be enabled.
           
           A stream with the "ACTIVE" status can be used as a source for installing profiles.  The packages that comprise the stream are also used when a matching package is installed directly.  In general, a stream can have this status if it is the default stream for the module and no stream has been explicitly enabled.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPrivateApplicationPackagesResult',
    'AwaitableGetPrivateApplicationPackagesResult',
    'get_private_application_packages',
    'get_private_application_packages_output',
]

@pulumi.output_type
class GetPrivateApplicationPackagesResult:
    """
    A collection of values returned by getPrivateApplicationPackages.
    """
    def __init__(__self__, display_name=None, filters=None, id=None, package_types=None, private_application_id=None, private_application_package_collections=None, private_application_package_id=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if package_types and not isinstance(package_types, list):
            raise TypeError("Expected argument 'package_types' to be a list")
        pulumi.set(__self__, "package_types", package_types)
        if private_application_id and not isinstance(private_application_id, str):
            raise TypeError("Expected argument 'private_application_id' to be a str")
        pulumi.set(__self__, "private_application_id", private_application_id)
        if private_application_package_collections and not isinstance(private_application_package_collections, list):
            raise TypeError("Expected argument 'private_application_package_collections' to be a list")
        pulumi.set(__self__, "private_application_package_collections", private_application_package_collections)
        if private_application_package_id and not isinstance(private_application_package_id, str):
            raise TypeError("Expected argument 'private_application_package_id' to be a str")
        pulumi.set(__self__, "private_application_package_id", private_application_package_id)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The display name of the package.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetPrivateApplicationPackagesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="packageTypes")
    def package_types(self) -> Optional[Sequence[str]]:
        """
        The specified package's type.
        """
        return pulumi.get(self, "package_types")

    @property
    @pulumi.getter(name="privateApplicationId")
    def private_application_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private application where the package is hosted.
        """
        return pulumi.get(self, "private_application_id")

    @property
    @pulumi.getter(name="privateApplicationPackageCollections")
    def private_application_package_collections(self) -> Sequence['outputs.GetPrivateApplicationPackagesPrivateApplicationPackageCollectionResult']:
        """
        The list of private_application_package_collection.
        """
        return pulumi.get(self, "private_application_package_collections")

    @property
    @pulumi.getter(name="privateApplicationPackageId")
    def private_application_package_id(self) -> Optional[str]:
        return pulumi.get(self, "private_application_package_id")


class AwaitableGetPrivateApplicationPackagesResult(GetPrivateApplicationPackagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateApplicationPackagesResult(
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            package_types=self.package_types,
            private_application_id=self.private_application_id,
            private_application_package_collections=self.private_application_package_collections,
            private_application_package_id=self.private_application_package_id)


def get_private_application_packages(display_name: Optional[str] = None,
                                     filters: Optional[Sequence[pulumi.InputType['GetPrivateApplicationPackagesFilterArgs']]] = None,
                                     package_types: Optional[Sequence[str]] = None,
                                     private_application_id: Optional[str] = None,
                                     private_application_package_id: Optional[str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateApplicationPackagesResult:
    """
    This data source provides the list of Private Application Packages in Oracle Cloud Infrastructure Service Catalog service.

    Lists the packages in the specified private application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_private_application_packages = oci.ServiceCatalog.get_private_application_packages(private_application_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        package_types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        private_application_package_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: Exact match name filter.
    :param Sequence[str] package_types: Name of the package type. If multiple package types are provided, then any resource with one or more matching package types will be returned.
    :param str private_application_id: The unique identifier for the private application.
    :param str private_application_package_id: The unique identifier for the private application package.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['packageTypes'] = package_types
    __args__['privateApplicationId'] = private_application_id
    __args__['privateApplicationPackageId'] = private_application_package_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ServiceCatalog/getPrivateApplicationPackages:getPrivateApplicationPackages', __args__, opts=opts, typ=GetPrivateApplicationPackagesResult).value

    return AwaitableGetPrivateApplicationPackagesResult(
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        package_types=__ret__.package_types,
        private_application_id=__ret__.private_application_id,
        private_application_package_collections=__ret__.private_application_package_collections,
        private_application_package_id=__ret__.private_application_package_id)


@_utilities.lift_output_func(get_private_application_packages)
def get_private_application_packages_output(display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                            filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetPrivateApplicationPackagesFilterArgs']]]]] = None,
                                            package_types: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                            private_application_id: Optional[pulumi.Input[str]] = None,
                                            private_application_package_id: Optional[pulumi.Input[Optional[str]]] = None,
                                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPrivateApplicationPackagesResult]:
    """
    This data source provides the list of Private Application Packages in Oracle Cloud Infrastructure Service Catalog service.

    Lists the packages in the specified private application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_private_application_packages = oci.ServiceCatalog.get_private_application_packages(private_application_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        package_types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        private_application_package_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: Exact match name filter.
    :param Sequence[str] package_types: Name of the package type. If multiple package types are provided, then any resource with one or more matching package types will be returned.
    :param str private_application_id: The unique identifier for the private application.
    :param str private_application_package_id: The unique identifier for the private application package.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnrollmentStatusResult',
    'AwaitableGetEnrollmentStatusResult',
    'get_enrollment_status',
    'get_enrollment_status_output',
]

@pulumi.output_type
class GetEnrollmentStatusResult:
    """
    A collection of values returned by getEnrollmentStatus.
    """
    def __init__(__self__, compartment_id=None, enrollment_status_id=None, id=None, state=None, status=None, status_reason=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if enrollment_status_id and not isinstance(enrollment_status_id, str):
            raise TypeError("Expected argument 'enrollment_status_id' to be a str")
        pulumi.set(__self__, "enrollment_status_id", enrollment_status_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if status_reason and not isinstance(status_reason, str):
            raise TypeError("Expected argument 'status_reason' to be a str")
        pulumi.set(__self__, "status_reason", status_reason)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="enrollmentStatusId")
    def enrollment_status_id(self) -> str:
        return pulumi.get(self, "enrollment_status_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the enrollment status.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The enrollment status' current state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The current Cloud Advisor enrollment status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusReason")
    def status_reason(self) -> str:
        """
        The reason for the enrollment status of the tenancy.
        """
        return pulumi.get(self, "status_reason")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the enrollment status was created, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the enrollment status was last updated, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetEnrollmentStatusResult(GetEnrollmentStatusResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnrollmentStatusResult(
            compartment_id=self.compartment_id,
            enrollment_status_id=self.enrollment_status_id,
            id=self.id,
            state=self.state,
            status=self.status,
            status_reason=self.status_reason,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_enrollment_status(enrollment_status_id: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnrollmentStatusResult:
    """
    This data source provides details about a specific Enrollment Status resource in Oracle Cloud Infrastructure Optimizer service.

    Gets the Cloud Advisor enrollment status.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_enrollment_status = oci.Optimizer.get_enrollment_status(enrollment_status_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str enrollment_status_id: The unique OCID associated with the enrollment status.
    """
    __args__ = dict()
    __args__['enrollmentStatusId'] = enrollment_status_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Optimizer/getEnrollmentStatus:getEnrollmentStatus', __args__, opts=opts, typ=GetEnrollmentStatusResult).value

    return AwaitableGetEnrollmentStatusResult(
        compartment_id=__ret__.compartment_id,
        enrollment_status_id=__ret__.enrollment_status_id,
        id=__ret__.id,
        state=__ret__.state,
        status=__ret__.status,
        status_reason=__ret__.status_reason,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_enrollment_status)
def get_enrollment_status_output(enrollment_status_id: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnrollmentStatusResult]:
    """
    This data source provides details about a specific Enrollment Status resource in Oracle Cloud Infrastructure Optimizer service.

    Gets the Cloud Advisor enrollment status.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_enrollment_status = oci.Optimizer.get_enrollment_status(enrollment_status_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str enrollment_status_id: The unique OCID associated with the enrollment status.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetReportDefinitionResult',
    'AwaitableGetReportDefinitionResult',
    'get_report_definition',
    'get_report_definition_output',
]

@pulumi.output_type
class GetReportDefinitionResult:
    """
    A collection of values returned by getReportDefinition.
    """
    def __init__(__self__, category=None, column_filters=None, column_infos=None, column_sortings=None, compartment_id=None, compliance_standards=None, data_source=None, defined_tags=None, description=None, display_name=None, display_order=None, freeform_tags=None, id=None, is_seeded=None, parent_id=None, record_time_span=None, report_definition_id=None, schedule=None, scheduled_report_compartment_id=None, scheduled_report_mime_type=None, scheduled_report_name=None, scheduled_report_row_limit=None, scim_filter=None, state=None, summaries=None, system_tags=None, time_created=None, time_updated=None):
        if category and not isinstance(category, str):
            raise TypeError("Expected argument 'category' to be a str")
        pulumi.set(__self__, "category", category)
        if column_filters and not isinstance(column_filters, list):
            raise TypeError("Expected argument 'column_filters' to be a list")
        pulumi.set(__self__, "column_filters", column_filters)
        if column_infos and not isinstance(column_infos, list):
            raise TypeError("Expected argument 'column_infos' to be a list")
        pulumi.set(__self__, "column_infos", column_infos)
        if column_sortings and not isinstance(column_sortings, list):
            raise TypeError("Expected argument 'column_sortings' to be a list")
        pulumi.set(__self__, "column_sortings", column_sortings)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compliance_standards and not isinstance(compliance_standards, list):
            raise TypeError("Expected argument 'compliance_standards' to be a list")
        pulumi.set(__self__, "compliance_standards", compliance_standards)
        if data_source and not isinstance(data_source, str):
            raise TypeError("Expected argument 'data_source' to be a str")
        pulumi.set(__self__, "data_source", data_source)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if display_order and not isinstance(display_order, int):
            raise TypeError("Expected argument 'display_order' to be a int")
        pulumi.set(__self__, "display_order", display_order)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_seeded and not isinstance(is_seeded, bool):
            raise TypeError("Expected argument 'is_seeded' to be a bool")
        pulumi.set(__self__, "is_seeded", is_seeded)
        if parent_id and not isinstance(parent_id, str):
            raise TypeError("Expected argument 'parent_id' to be a str")
        pulumi.set(__self__, "parent_id", parent_id)
        if record_time_span and not isinstance(record_time_span, str):
            raise TypeError("Expected argument 'record_time_span' to be a str")
        pulumi.set(__self__, "record_time_span", record_time_span)
        if report_definition_id and not isinstance(report_definition_id, str):
            raise TypeError("Expected argument 'report_definition_id' to be a str")
        pulumi.set(__self__, "report_definition_id", report_definition_id)
        if schedule and not isinstance(schedule, str):
            raise TypeError("Expected argument 'schedule' to be a str")
        pulumi.set(__self__, "schedule", schedule)
        if scheduled_report_compartment_id and not isinstance(scheduled_report_compartment_id, str):
            raise TypeError("Expected argument 'scheduled_report_compartment_id' to be a str")
        pulumi.set(__self__, "scheduled_report_compartment_id", scheduled_report_compartment_id)
        if scheduled_report_mime_type and not isinstance(scheduled_report_mime_type, str):
            raise TypeError("Expected argument 'scheduled_report_mime_type' to be a str")
        pulumi.set(__self__, "scheduled_report_mime_type", scheduled_report_mime_type)
        if scheduled_report_name and not isinstance(scheduled_report_name, str):
            raise TypeError("Expected argument 'scheduled_report_name' to be a str")
        pulumi.set(__self__, "scheduled_report_name", scheduled_report_name)
        if scheduled_report_row_limit and not isinstance(scheduled_report_row_limit, int):
            raise TypeError("Expected argument 'scheduled_report_row_limit' to be a int")
        pulumi.set(__self__, "scheduled_report_row_limit", scheduled_report_row_limit)
        if scim_filter and not isinstance(scim_filter, str):
            raise TypeError("Expected argument 'scim_filter' to be a str")
        pulumi.set(__self__, "scim_filter", scim_filter)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if summaries and not isinstance(summaries, list):
            raise TypeError("Expected argument 'summaries' to be a list")
        pulumi.set(__self__, "summaries", summaries)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter
    def category(self) -> str:
        """
        Specifies the name of the category that this report belongs to.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="columnFilters")
    def column_filters(self) -> Sequence['outputs.GetReportDefinitionColumnFilterResult']:
        """
        An array of columnFilter objects. A columnFilter object stores all information about a column filter including field name, an operator, one or more expressions, if the filter is enabled, or if the filter is hidden.
        """
        return pulumi.get(self, "column_filters")

    @property
    @pulumi.getter(name="columnInfos")
    def column_infos(self) -> Sequence['outputs.GetReportDefinitionColumnInfoResult']:
        """
        An array of column objects in the order (left to right) displayed in the report. A column object stores all information about a column, including the name displayed on the UI, corresponding field name in the data source, data type of the column, and column visibility (if the column is visible to the user).
        """
        return pulumi.get(self, "column_infos")

    @property
    @pulumi.getter(name="columnSortings")
    def column_sortings(self) -> Sequence['outputs.GetReportDefinitionColumnSortingResult']:
        """
        An array of column sorting objects. Each column sorting object stores the column name to be sorted and if the sorting is in ascending order; sorting is done by the first column in the array, then by the second column in the array, etc.
        """
        return pulumi.get(self, "column_sortings")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment containing the report definition.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="complianceStandards")
    def compliance_standards(self) -> Sequence[str]:
        """
        The list of the data protection regulations/standards used in the report that will help demonstrate compliance.
        """
        return pulumi.get(self, "compliance_standards")

    @property
    @pulumi.getter(name="dataSource")
    def data_source(self) -> str:
        """
        Specifies the name of a resource that provides data for the report. For example alerts, events.
        """
        return pulumi.get(self, "data_source")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A description of the report definition.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Name of the report definition.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="displayOrder")
    def display_order(self) -> int:
        """
        Specifies the order in which the summary must be displayed.
        """
        return pulumi.get(self, "display_order")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the report definition.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isSeeded")
    def is_seeded(self) -> bool:
        """
        Signifies whether the definition is seeded or user defined. Values can either be 'true' or 'false'.
        """
        return pulumi.get(self, "is_seeded")

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> str:
        """
        The OCID of the parent report definition. In the case of seeded report definition, this is same as definition OCID.
        """
        return pulumi.get(self, "parent_id")

    @property
    @pulumi.getter(name="recordTimeSpan")
    def record_time_span(self) -> str:
        """
        The time span for the records in the report to be scheduled. <period-value><period> Allowed period strings - "H","D","M","Y" Each of the above fields potentially introduce constraints. A workRequest is created only when period-value satisfies all the constraints. Constraints introduced: 1. period = H (The allowed range for period-value is [1, 23]) 2. period = D (The allowed range for period-value is [1, 30]) 3. period = M (The allowed range for period-value is [1, 11]) 4. period = Y (The minimum period-value is 1)
        """
        return pulumi.get(self, "record_time_span")

    @property
    @pulumi.getter(name="reportDefinitionId")
    def report_definition_id(self) -> str:
        return pulumi.get(self, "report_definition_id")

    @property
    @pulumi.getter
    def schedule(self) -> str:
        """
        The schedule to generate the report periodically in the specified format: <version-string>;<version-specific-schedule>
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="scheduledReportCompartmentId")
    def scheduled_report_compartment_id(self) -> str:
        """
        The OCID of the compartment in which the scheduled resource should be created.
        """
        return pulumi.get(self, "scheduled_report_compartment_id")

    @property
    @pulumi.getter(name="scheduledReportMimeType")
    def scheduled_report_mime_type(self) -> str:
        """
        Specifies the format of the report ( either XLS or PDF )
        """
        return pulumi.get(self, "scheduled_report_mime_type")

    @property
    @pulumi.getter(name="scheduledReportName")
    def scheduled_report_name(self) -> str:
        """
        The name of the report to be scheduled.
        """
        return pulumi.get(self, "scheduled_report_name")

    @property
    @pulumi.getter(name="scheduledReportRowLimit")
    def scheduled_report_row_limit(self) -> int:
        """
        Specifies the limit on the number of rows in the report.
        """
        return pulumi.get(self, "scheduled_report_row_limit")

    @property
    @pulumi.getter(name="scimFilter")
    def scim_filter(self) -> str:
        """
        Additional scim filters used to get the specific summary.
        """
        return pulumi.get(self, "scim_filter")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the report.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def summaries(self) -> Sequence['outputs.GetReportDefinitionSummaryResult']:
        """
        An array of report summary objects in the order (left to right)  displayed in the report.  A  report summary object stores all information about summary of report to be displayed, including the name displayed on UI, the display order, corresponding group by and count of values, summary visibility (if the summary is visible to user).
        """
        return pulumi.get(self, "summaries")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        Specifies the data and time the report definition was created.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the report definition was update.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetReportDefinitionResult(GetReportDefinitionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReportDefinitionResult(
            category=self.category,
            column_filters=self.column_filters,
            column_infos=self.column_infos,
            column_sortings=self.column_sortings,
            compartment_id=self.compartment_id,
            compliance_standards=self.compliance_standards,
            data_source=self.data_source,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            display_order=self.display_order,
            freeform_tags=self.freeform_tags,
            id=self.id,
            is_seeded=self.is_seeded,
            parent_id=self.parent_id,
            record_time_span=self.record_time_span,
            report_definition_id=self.report_definition_id,
            schedule=self.schedule,
            scheduled_report_compartment_id=self.scheduled_report_compartment_id,
            scheduled_report_mime_type=self.scheduled_report_mime_type,
            scheduled_report_name=self.scheduled_report_name,
            scheduled_report_row_limit=self.scheduled_report_row_limit,
            scim_filter=self.scim_filter,
            state=self.state,
            summaries=self.summaries,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_report_definition(report_definition_id: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReportDefinitionResult:
    """
    This data source provides details about a specific Report Definition resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of report definition specified by the identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_report_definition = oci.DataSafe.get_report_definition(report_definition_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str report_definition_id: Unique report definition identifier
    """
    __args__ = dict()
    __args__['reportDefinitionId'] = report_definition_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getReportDefinition:getReportDefinition', __args__, opts=opts, typ=GetReportDefinitionResult).value

    return AwaitableGetReportDefinitionResult(
        category=__ret__.category,
        column_filters=__ret__.column_filters,
        column_infos=__ret__.column_infos,
        column_sortings=__ret__.column_sortings,
        compartment_id=__ret__.compartment_id,
        compliance_standards=__ret__.compliance_standards,
        data_source=__ret__.data_source,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        display_order=__ret__.display_order,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        is_seeded=__ret__.is_seeded,
        parent_id=__ret__.parent_id,
        record_time_span=__ret__.record_time_span,
        report_definition_id=__ret__.report_definition_id,
        schedule=__ret__.schedule,
        scheduled_report_compartment_id=__ret__.scheduled_report_compartment_id,
        scheduled_report_mime_type=__ret__.scheduled_report_mime_type,
        scheduled_report_name=__ret__.scheduled_report_name,
        scheduled_report_row_limit=__ret__.scheduled_report_row_limit,
        scim_filter=__ret__.scim_filter,
        state=__ret__.state,
        summaries=__ret__.summaries,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_report_definition)
def get_report_definition_output(report_definition_id: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetReportDefinitionResult]:
    """
    This data source provides details about a specific Report Definition resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of report definition specified by the identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_report_definition = oci.DataSafe.get_report_definition(report_definition_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str report_definition_id: Unique report definition identifier
    """
    ...
